#
# spec file for package libusnic_verbs-rdmav2
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


# Version magic
%{!?usnic_release: %define usnic_release SUSE_%{expand:%(date +%Y%m%d_%H%M)}} 

%define extra_version .sles12sp0

Name:           libusnic_verbs-rdmav2
Summary:        Cisco UCS InfiniBand HCA Userspace Driver
License:        BSD-2-Clause
Group:          System/Libraries
Version:        1.1.0.237
Release:        5.13
Url:            http://cisco.com/
Source:         libusnic_verbs-%{version}%{extra_version}.src.tar.gz
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libibverbs-devel >= 1.1.5
BuildRequires:  libnl3-devel
BuildRequires:  libtool
BuildRequires:  pkgconfig

# Enable valgrind?
%define config_valgrind --without-valgrind
%{?valgrind: %define version_b %{version}_vg}

#Supplements:    modalias()

%description
libusnic_verbs provides a device-specific userspace driver for Cisco
Virtual NICs for use with the libibverbs library.

%package     -n usnic_udp_pingpong
Summary:        Small usnic program
Group:          System/Libraries
Provides:       %{name}-pingpong = %{version}
Obsoletes:      %{name}-pingpong < %{version}

%description -n usnic_udp_pingpong
The cojntained program runs a pingpong traffic test between two servers
through usnic devices.

%prep
%setup -q -n libusnic_verbs-%{version}%{extra_version}
mkdir -p m4

%build
autoreconf -fi
%configure --disable-silent-rules
make %{?_smp_mflags}

%install
make DESTDIR=%{buildroot} install install-usnicconfDATA
rm %{buildroot}%{_libdir}/*.la %{buildroot}%{_libdir}/libusnic_verbs.so

%files
%defattr(-,root,root,-)
%doc AUTHORS COPYING README KNOWN_ISSUES
%{_libdir}/libusnic_verbs-rdmav2.so
%dir %_sysconfdir/libibverbs.d
%config(noreplace) %{_sysconfdir}/libibverbs.d/usnic.driver

%files -n usnic_udp_pingpong
%defattr(-,root,root,-)
%{_bindir}/usnic_udp_pingpong

%changelog
* Wed Feb 25 2015 mgorse@suse.com
- Update to latest version 1.1.0.237:
  * Added vendor field in usNIC RPM metadata
  * Added capability reporting function.
  * The alloc_context routine will now return a structure specifying the
    capabilities of the device and driver.  This is important so that Intel MPI
    can detect whether the driver supports CQ sharing.
  * move usnic_ib_abi.h from libusnic_verbs to common directory so other
    libraries may access it
* Thu Jul 17 2014 pth@suse.de
- Rename sub package to usnic_udp_pingpong and add appropriate
  Provides/Obsoletes Entries.
* Wed Jul 16 2014 pth@suse.de
- Update to latest code drop from Cisco that now has correct licenses
  in pingpong/usnic_verbs_util.[ch] (only change).
* Fri Jul 11 2014 pth@suse.de
- Update to latest code drop from Cisco (bnc#861155) :
  * Print local and remote addresses as IP instead of GIDs.
    In addition, removed gid index in option as it is not needed, fixed a
    compiling warning, and changed the latency measurement to time used for half
    round trip.
  * Added a new vnic API to seperate devcmd initialization from
    vnic_dev_register
    Also added a fallback arugment for function vnic_dev_cmd_init(), which would
    fallback to the original devcmd if devcmd2 resource is not present and
    fallback is required.
  * ibv_devinfo command is not currently showing usnic firmware version
* Wed Jul  9 2014 pth@suse.de
- Remove bogus source URL.
* Tue Jun  3 2014 pth@suse.de
- Update to OFED 3.12 final.
* Tue May 13 2014 pth@suse.de
- Update to the latest code drop 1.1.0.192 from Cisco (bnc#861155):
  * Change error return code to positive for certain functions.
  * Remove the limit for 4k MTU in usnic_udp_pingpong
  * Removed lingering TMP_VNIC_CMD_DIR variable
  * Fixed ibv_devinfo command to show the usnic firmware version
  * Added the ability to report packet and byte statistics from libusnic_verbs
    If USNIC_QP_STATS is defined in the environment, the ibv_destroy_qp()
    call will print per-QP stastics to stdout.  Packet count is number of
    IP packets sent, and byte count is number of bytes send, counting IP
    headers (but not ether headers)
  * Change create_ah implemenation to use ioctl instead of libnl to query arp
    entry.
  * Fix container_of re-definition warnings
  * Bump libusnic_verbs version number for changing transport format to
    ip/udp.
* Wed Mar 26 2014 pth@suse.de
- Update to the latest code drop 1.1.0.166 from Cisco (bnc#861155):
  * Fix a bug causing create_qp() failure when multiple contexts are
    created for a single device.
  * Added pthread_mutex_init call for usnic_context.vf_lst_lock.
* Thu Mar 20 2014 pth@suse.de
- Updating to 1.0.2.162, the final code drop from Cisco (bnc#861155)
- usnic-autotools.patch dropped as changes are upstream.
- usnic-prototype.patch dropped as it's not needed anymore.
- Put the pingpong test tool into its own package.
* Mon Feb 10 2014 pth@suse.de
- Fix license specification.
* Fri Jan 31 2014 pth@suse.de
- Include LIBNL_CFLAGS only when libnl is used.
* Thu Jan 30 2014 pth@suse.de
- Initial SUSE package.
- Switch on automake warnings and fix most of the warnings
  it now issues: usnic-autotools.patch
- Fix incomplete prototypes in src/usnic_transport_udp.c:
  usnic-prototype.patch.
- Code needs at least libnl 1.1 so add a BuildRequires
  for libnl3-devel
* Mon Apr  8 2013 jsquyres@cisco.com
- First release
